| rasterio0 | R Documentation |
Basic function to create the window parameters as used by GDAL RasterIO.
rasterio0(
src_offset,
src_dim,
out_dim = src_dim,
resample = "NearestNeighbour"
)
src_offset |
index offset (0-based, top left) |
src_dim |
source dimension (XY) |
out_dim |
output dimension (XY, optional src_dim will be used if not set) |
resample |
resampling algorithm for GDAL see details |
Resampling algorithm is one of 'NearestNeighbour' (default), 'Average', 'Bilinear', 'Cubic', 'CubicSpline', 'Gauss', 'Lanczos', 'Mode', but more may be available given the version of GDAL in use.
numeric vector of values specifying offset, source dimension, output dimension
rasterio0(c(0L, 0L), src_dim = c(24L, 10L))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.