vaster_boundary: Grid boundary in native resolution

View source: R/coordinates.R

vaster_boundaryR Documentation

Grid boundary in native resolution

Description

Generates the coordinates around a grid boundary, with a coordinate for each grid cell corner.

Usage

vaster_boundary(dimension, extent = NULL)

Arguments

dimension

integer ncol, nrow

extent

numeric extent xmin,xmax,ymin,ymax

Details

The orientation is starts along the bottom and goes counter-clockwise.

Value

matrix of xy coordinates

Examples

vaster_boundary(c(3, 4))

plot(vaster_boundary(c(36, 18), c(-180, 180, -90, 90)))

vaster documentation built on March 10, 2026, 5:08 p.m.