vaster_boundary_cell: Grid boundary cell index

View source: R/coordinates.R

vaster_boundary_cellR Documentation

Grid boundary cell index

Description

This is for indexing coordinate arrays to get their values (the cell index of the outer row and columns).

Usage

vaster_boundary_cell(dimension)

Arguments

dimension

integer ncol, nrow

Details

The orientation is the same as for vaster_boundary().

Value

a matrix of xy coordinates

Examples

vaster_boundary_cell(c(3, 4))
cell <- vaster_boundary_cell(c(3, 4))
plot(vaster_boundary(c(3, 4)))
text(xy <- xy_from_cell(c(3, 4), cell = vaster_boundary_cell(c(3, 4))), lab = cell)
lines(xy)

vaster documentation built on March 10, 2026, 5:08 p.m.