| vaster_boundary | R Documentation |
Generates the coordinates around a grid boundary, with a coordinate for each grid cell corner.
vaster_boundary(dimension, extent = NULL)
dimension |
integer ncol, nrow |
extent |
numeric extent xmin,xmax,ymin,ymax |
The orientation is starts along the bottom and goes counter-clockwise.
matrix of xy coordinates
vaster_boundary(c(3, 4))
plot(vaster_boundary(c(36, 18), c(-180, 180, -90, 90)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.