| vaster_boundary_cell | R Documentation |
This is for indexing coordinate arrays to get their values (the cell index of the outer row and columns).
vaster_boundary_cell(dimension)
dimension |
integer ncol, nrow |
The orientation is the same as for vaster_boundary().
a matrix of xy coordinates
vaster_boundary_cell(c(3, 4))
cell <- vaster_boundary_cell(c(3, 4))
plot(vaster_boundary(c(3, 4)))
text(xy <- xy_from_cell(c(3, 4), cell = vaster_boundary_cell(c(3, 4))), lab = cell)
lines(xy)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.